@@ -32,6 +32,7 @@ import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Hashtable;
 import java.util.List;
+import java.util.Locale;
 import java.util.Set;
 import java.util.Vector;
 
@@ -103,8 +104,11 @@ public class XMLParser extends DefaultHandler implements LexicalHandler, DeclHan
     factory.setNamespaceAware(true);
     factory.setValidating(false);
 
+
     try
     {
+      factory.setFeature("http://xml.org/sax/features/external-general-entities", false);
+      factory.setFeature("http://xml.org/sax/features/external-parameter-entities", false);
       factory.setFeature("http://xml.org/sax/features/validation", false);
       if (context.version == EPUBVersion.VERSION_3)
       {
@@ -981,7 +985,7 @@ public class XMLParser extends DefaultHandler implements LexicalHandler, DeclHan
     }
 
     String encoding = header.substring(encIndex + 1, encEnd);
-    return encoding.toUpperCase();
+    return encoding.toUpperCase(Locale.ROOT);
   }
 
   static
